
clear
set more off
capture set max_memory 500M /* for stata 12 */
capture set mem 500M		

cap log close

**********************************************************************************
*
* CREATING WAVE 5 BASIC VARIABLES
*
**********************************************************************************


use "$y5data\hh_sec_a.dta", clear
count

keep hh_a06 y5_hhid-int_month_code int_month_year tracking_class

rename hh_a01_1 region
rename hh_a02_1 district

*~*~*~*~*~*~*~*~*~*~*
* HOUSEHOLD WEIGHT 	*
*~*~*~*~*~*~*~*~*~*~*

gen hhweight = y5_panelweight
count if y5_panelweight==.

label var hhweight "Sampling weights, y5_panelweight"

gen hhweight2 = y5_crossweight
count if y5_crossweight==.

label var hhweight2 "Sampling weights, y5_crossweight"

*~*~*~*~*~*~*~*~*~*~*
* URBAN/RURAL/MIXED	*
*~*~*~*~*~*~*~*~*~*~*

describe y5_rural
tab y5_rural, m

clonevar urban = y5_rural 
tab urban, m

*~*~*~*~*
* AREA  *
*~*~*~*~*

* Current location of household (for analysis)
gen area=1 if region == 7
replace area=2 if region != 7 & urban == 2
replace area=3 if region != 7 & urban == 1
replace area=4 if region != 7 & inrange(region,51,55)

label define AREA 1 "Dar es Salaam" 2 "Rest of urban" 3 "Rural" 4 "Zanzibar"
label val area AREA
label var area "Area"
tab area, m

*~*~*~*~*~*~*
* MAINLAND 	*
*~*~*~*~*~*~*

* Mainland is region code that is not in the 50s *
* Region code 51-55 is Zanzibar *

gen mainland = 1 if inrange(region,1,26)
replace mainland = 2 if inrange(region,51,55)

label define MAINLAND 1 "Mainland" 2 "Zanzibar"
label value mainland MAINLAND
label var mainland "Mainland or Zanzibar"

tab mainland, m

*******************
* Cluster/Strata **
*******************

gen strata = domain if !missing(domain)				/* Panel households */
replace strata = area if missing(domain)			/* New households */

label define strata 1 "Dar es Salaam" 2 "Rest of urban" 3 "Rural" 4 "Zanzibar"
label val strata strata
label var strata Strata
tab strata, m

clonevar y5_cluster2 = y5_cluster
replace y5_cluster2 = subinstr(y5_cluster2, "-", "", .)
destring y5_cluster2, replace

gen cluster = clusterid								/* Panel households */
replace cluster = y5_cluster2 if cluster == .		/* New households */
label var cluster Cluster
format cluster %12.0g

*~*~*~*~*~*~*~*~*~*~*
* DATE OF INTERVIEW *
*~*~*~*~*~*~*~*~*~*~*

* Check dates *
gen m = int_month_code
gen y = .
	replace y = 2020 if int_month_year == 1
	replace y = 2021 if inrange(int_month_year, 2, 13)
	replace y = 2022 if int_month_year == 14
tab m y, m

gen intmonth = m
gen intyear  = y
label var intmonth "Month of interview"
label var intyear "Year of interview"
tab intmonth intyear, m

	gen month = .

replace month = intmonth

* HHs interviewed in months before January 2021 will be considered January 2021
* HHs interviewed in months after December 2021 will be considered December 2021

#delimit;
label define month 1 "January 2021"	
				   2 "February"
				   3 "March"
				   4 "April"
				   5 "May" 
				   6 "June"
				   7 "July"
				   8 "August" 
				   9 "September"
				   10 "October" 
				   11 "November"
				   12 "December 2021", replace
;
#delimit cr
label var month Month
label values month month
tab month, m

* listing cases with missing or incorrect dates
list y5_hhid region district int_month* if month==., nol sep(0)

* Creating a quarter variable
tab month, m
label list month

gen quarter = irecode(month, 3, 6, 9, 12) + 1

label define quarter 1 "Jan-Mar 2021" 2 "Apr-May 2021" 3 "Jul-Sep 2021" 4 "Oct-Dec 2021", replace
label var quarter "Quarter of fieldwork"
label val quarter quarter

tab quarter, m
tabstat month, by(quarter) s(min max)

*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*
* HOUSEHOLD SIZE/ADULT EQUIV *
*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*

preserve

	use "$y5data/hh_sec_b.dta", clear

	renpfix hh_b b

*******************************************
* How many households are in the roster?
*******************************************

egen x = group(y5_hhid)
summarize x
tab y5_hhid if x==., m

bysort y5_hhid : gen first = cond(_n==1,1,0)
tab first, m
count if first==1
count if first==1 & x==.

***********************
* Adult Equivalents
***********************

	gen sex = b02
	gen age = b04
	summ sex age
	tab1 sex age, m

/* Adult equivalence factors created using WHO nutritional weight standards
   Collier et al, 1986 */

	gen adulteqfactor = .
	replace adulteqfactor = 0.40 if inrange(age,0,2)
	replace adulteqfactor = 0.48 if inrange(age,3,4)
	replace adulteqfactor = 0.56 if inrange(age,5,6)
	replace adulteqfactor = 0.64 if inrange(age,7,8)
	replace adulteqfactor = 0.76 if inrange(age,9,10)
	replace adulteqfactor = 0.80 if inrange(age,11,12)  & sex==1
	replace adulteqfactor = 0.88 if inrange(age,11,12)  & sex==2
	replace adulteqfactor = 1.00 if inrange(age,13,14)
	replace adulteqfactor = 1.20 if inrange(age,15,18)  & sex==1
	replace adulteqfactor = 1.00 if inrange(age,15,18)  & sex==2
	replace adulteqfactor = 1.00 if inrange(age,19,59)  & sex==1
	replace adulteqfactor = 0.88 if inrange(age,19,59)  & sex==2
	replace adulteqfactor = 0.88 if inrange(age,60,108) & sex==1
	replace adulteqfactor = 0.72 if inrange(age,60,105) & sex==2
	tab adulteqfactor, m

	list if adulteqfactor==.

	* Adult equivalence factors adjusted for males age range 60-105 to 60-108

	inspect adulteqfactor
	summ adulteqfactor, detail

	gen femalehead = 1 if b05==1 & b02==2
	replace femalehead = 0 if missing(femalehead)

	tab femalehead, m

	collapse (max) femalehead (count) hhsize=indidy5 (sum) adulteq=adulteqfactor, by(y5_hhid)

	label var femalehead "Female headed household"
	label var hhsize "Household size"
	label var adulteq "Adult-equivalents in the household"

	tempfile roster
	save `roster', replace

restore

merge 1:1 y5_hhid using `roster'
assert _m==3
drop _m

**************
* Summary
**************

keep y5_hhid y4_hhid cluster hhweight hhweight2 region district month quarter mainland femalehead hhsize adulteq intyear ///
	intmonth  strata urban area tracking_class

order y5_hhid y4_hhid tracking_class cluster strata hhweight hhweight2 urban area region district month quarter ///
	  mainland femalehead hhsize adulteq intyear intmonth quarter

compress
describe
sort y5_hhid

save "$output/basicvars_y5.dta", replace

clear
capture log close
